@@ -255,7 +255,7 @@
 #define INSTALL_SCRIPTDIR "/usr/local/mysql/bin"
 #define INSTALL_MYSQLDATADIR "/usr/local/mysql/data"
 #define INSTALL_MYSQLKEYRINGDIR "/usr/local/mysql/keyring"
-#define INSTALL_PLUGINTESTDIR "/build/percona-server/src/percona-server-5.7.15-9/plugin/audit_log/tests;/build/percona-server/src/percona-server-5.7.15-9/plugin/query_response_time/tests;/build/percona-server/src/percona-server-5.7.15-9/plugin/scalability_metrics/tests"
+#define INSTALL_PLUGINTESTDIR "/build/percona-server/src/percona-server-5.7.16-10/plugin/audit_log/tests;/build/percona-server/src/percona-server-5.7.16-10/plugin/query_response_time/tests;/build/percona-server/src/percona-server-5.7.16-10/plugin/scalability_metrics/tests"
 #define INSTALL_INFODIR "/usr/local/mysql/share/mysql/docs"
 #define INSTALL_MYSQLTESTDIR "/usr/local/mysql/mysql-test"
 #define INSTALL_DOCREADMEDIR "/usr/local/mysql/share/mysql"
@@ -391,15 +391,15 @@
 #define DOT_FRM_VERSION 6
 #define MYSQL_VERSION_MAJOR 5
 #define MYSQL_VERSION_MINOR 7
-#define MYSQL_VERSION_PATCH 15
-#define MYSQL_VERSION_EXTRA "-9"
+#define MYSQL_VERSION_PATCH 16
+#define MYSQL_VERSION_EXTRA "-10"
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 5.7.15-9"
+#define PACKAGE_STRING "MySQL Server 5.7.16-10"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "5.7.15-9"
-#define VERSION "5.7.15-9"
+#define PACKAGE_VERSION "5.7.16-10"
+#define VERSION "5.7.16-10"
 #define PROTOCOL_VERSION 10
 
 /*
@@ -446,7 +446,7 @@
 /* #undef HAVE_SOCKLEN_T */
 
 /* For --secure-file-priv */
-#define DEFAULT_SECURE_FILE_PRIV_DIR ""
+#define DEFAULT_SECURE_FILE_PRIV_DIR "NULL"
 #define DEFAULT_SECURE_FILE_PRIV_EMBEDDED_DIR "NULL"
 /* #undef HAVE_LIBNUMA */
 #define WITH_NUMA 1
